# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from strobesbufs.analyzers import analyzers_service_pb2 as strobesbufs_dot_analyzers_dot_analyzers__service__pb2


class RunnerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.RunTask = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/RunTask',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskResponse.FromString,
                )
        self.TaskStatus = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/TaskStatus',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusResponse.FromString,
                )
        self.StopTask = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/StopTask',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskResponse.FromString,
                )
        self.GetResults = channel.unary_unary(
                '/strobesbufs.analyzers.analyzer_service.RunnerService/GetResults',
                request_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsRequest.SerializeToString,
                response_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsResponse.FromString,
                )


class RunnerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def RunTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TaskStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopTask(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RunnerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'RunTask': grpc.unary_unary_rpc_method_handler(
                    servicer.RunTask,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskResponse.SerializeToString,
            ),
            'TaskStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.TaskStatus,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusResponse.SerializeToString,
            ),
            'StopTask': grpc.unary_unary_rpc_method_handler(
                    servicer.StopTask,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskResponse.SerializeToString,
            ),
            'GetResults': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResults,
                    request_deserializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsRequest.FromString,
                    response_serializer=strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'strobesbufs.analyzers.analyzer_service.RunnerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RunnerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def RunTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/RunTask',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.RunTaskResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TaskStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/TaskStatus',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.TaskStatusResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/StopTask',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.StopTaskResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/strobesbufs.analyzers.analyzer_service.RunnerService/GetResults',
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsRequest.SerializeToString,
            strobesbufs_dot_analyzers_dot_analyzers__service__pb2.GetResultsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/workflows/workflow.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strobesbufs.messier.tasks import task_pb2 as strobesbufs_dot_messier_dot_tasks_dot_task__pb2
from strobesbufs.messier import common_pb2 as strobesbufs_dot_messier_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/workflows/workflow.proto',
  package='strobesbufs.messier.workflow',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/workflows/workflow.proto\x12\x1cstrobesbufs.messier.workflow\x1a\x1fgoogle/protobuf/timestamp.proto\x1a$strobesbufs/messier/tasks/task.proto\x1a strobesbufs/messier/common.proto\"\xf4\x01\n\x08Workflow\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x02 \x01(\t\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\".strobesbufs.messier.common.Status\x12+\n\x07started\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05\x65nded\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x06 \x01(\t\x12-\n\x05tasks\x18\x07 \x03(\x0b\x32\x1e.strobesbufs.messier.task.Taskb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_tasks_dot_task__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_common__pb2.DESCRIPTOR,])




_WORKFLOW = _descriptor.Descriptor(
  name='Workflow',
  full_name='strobesbufs.messier.workflow.Workflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.messier.workflow.Workflow.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='author', full_name='strobesbufs.messier.workflow.Workflow.author', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.messier.workflow.Workflow.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started', full_name='strobesbufs.messier.workflow.Workflow.started', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ended', full_name='strobesbufs.messier.workflow.Workflow.ended', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='strobesbufs.messier.workflow.Workflow.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='strobesbufs.messier.workflow.Workflow.tasks', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=428,
)

_WORKFLOW.fields_by_name['status'].enum_type = strobesbufs_dot_messier_dot_common__pb2._STATUS
_WORKFLOW.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['ended'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_WORKFLOW.fields_by_name['tasks'].message_type = strobesbufs_dot_messier_dot_tasks_dot_task__pb2._TASK
DESCRIPTOR.message_types_by_name['Workflow'] = _WORKFLOW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Workflow = _reflection.GeneratedProtocolMessageType('Workflow', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOW,
  '__module__' : 'strobesbufs.messier.workflows.workflow_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.workflow.Workflow)
  })
_sym_db.RegisterMessage(Workflow)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/analyzers/analyzers_service.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.analyzers import analyzers_pb2 as strobesbufs_dot_analyzers_dot_analyzers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/analyzers/analyzers_service.proto',
  package='strobesbufs.analyzers.analyzer_service',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-strobesbufs/analyzers/analyzers_service.proto\x12&strobesbufs.analyzers.analyzer_service\x1a%strobesbufs/analyzers/analyzers.proto\"\xc7\x03\n\x0eRunTaskRequest\x12\x10\n\x08\x61nalyzer\x18\x01 \x01(\t\x12\x0b\n\x03vcs\x18\x02 \x01(\t\x12U\n\x08vcs_data\x18\x03 \x03(\x0b\x32\x43.strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry\x12W\n\tscan_data\x18\x04 \x03(\x0b\x32\x44.strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry\x12U\n\x08\x65nv_data\x18\x05 \x03(\x0b\x32\x43.strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry\x1a.\n\x0cVcsDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rScanDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0c\x45nvDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x0fRunTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"\x1f\n\x11TaskStatusRequest\x12\n\n\x02id\x18\x01 \x01(\t\"?\n\x12TaskStatusResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1d\n\x0fStopTaskRequest\x12\n\n\x02id\x18\x01 \x01(\t\"=\n\x10StopTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x11GetResultsRequest\x12\n\n\x02id\x18\x01 \x01(\t\"M\n\x12GetResultsResponse\x12\x37\n\x07results\x18\x01 \x01(\x0b\x32&.strobesbufs.analyzers.analyzer.Result2\x9e\x04\n\rRunnerService\x12|\n\x07RunTask\x12\x36.strobesbufs.analyzers.analyzer_service.RunTaskRequest\x1a\x37.strobesbufs.analyzers.analyzer_service.RunTaskResponse\"\x00\x12\x85\x01\n\nTaskStatus\x12\x39.strobesbufs.analyzers.analyzer_service.TaskStatusRequest\x1a:.strobesbufs.analyzers.analyzer_service.TaskStatusResponse\"\x00\x12\x7f\n\x08StopTask\x12\x37.strobesbufs.analyzers.analyzer_service.StopTaskRequest\x1a\x38.strobesbufs.analyzers.analyzer_service.StopTaskResponse\"\x00\x12\x85\x01\n\nGetResults\x12\x39.strobesbufs.analyzers.analyzer_service.GetResultsRequest\x1a:.strobesbufs.analyzers.analyzer_service.GetResultsResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[strobesbufs_dot_analyzers_dot_analyzers__pb2.DESCRIPTOR,])




_RUNTASKREQUEST_VCSDATAENTRY = _descriptor.Descriptor(
  name='VcsDataEntry',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=487,
)

_RUNTASKREQUEST_SCANDATAENTRY = _descriptor.Descriptor(
  name='ScanDataEntry',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=536,
)

_RUNTASKREQUEST_ENVDATAENTRY = _descriptor.Descriptor(
  name='EnvDataEntry',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=538,
  serialized_end=584,
)

_RUNTASKREQUEST = _descriptor.Descriptor(
  name='RunTaskRequest',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='analyzer', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.analyzer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcs', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.vcs', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vcs_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.vcs_data', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scan_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.scan_data', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='env_data', full_name='strobesbufs.analyzers.analyzer_service.RunTaskRequest.env_data', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RUNTASKREQUEST_VCSDATAENTRY, _RUNTASKREQUEST_SCANDATAENTRY, _RUNTASKREQUEST_ENVDATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=584,
)


_RUNTASKRESPONSE = _descriptor.Descriptor(
  name='RunTaskResponse',
  full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='strobesbufs.analyzers.analyzer_service.RunTaskResponse.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=586,
  serialized_end=647,
)


_TASKSTATUSREQUEST = _descriptor.Descriptor(
  name='TaskStatusRequest',
  full_name='strobesbufs.analyzers.analyzer_service.TaskStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=680,
)


_TASKSTATUSRESPONSE = _descriptor.Descriptor(
  name='TaskStatusResponse',
  full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.analyzers.analyzer_service.TaskStatusResponse.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=745,
)


_STOPTASKREQUEST = _descriptor.Descriptor(
  name='StopTaskRequest',
  full_name='strobesbufs.analyzers.analyzer_service.StopTaskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.StopTaskRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=776,
)


_STOPTASKRESPONSE = _descriptor.Descriptor(
  name='StopTaskResponse',
  full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.analyzers.analyzer_service.StopTaskResponse.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=839,
)


_GETRESULTSREQUEST = _descriptor.Descriptor(
  name='GetResultsRequest',
  full_name='strobesbufs.analyzers.analyzer_service.GetResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='strobesbufs.analyzers.analyzer_service.GetResultsRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=841,
  serialized_end=872,
)


_GETRESULTSRESPONSE = _descriptor.Descriptor(
  name='GetResultsResponse',
  full_name='strobesbufs.analyzers.analyzer_service.GetResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='strobesbufs.analyzers.analyzer_service.GetResultsResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=951,
)

_RUNTASKREQUEST_VCSDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST_SCANDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST_ENVDATAENTRY.containing_type = _RUNTASKREQUEST
_RUNTASKREQUEST.fields_by_name['vcs_data'].message_type = _RUNTASKREQUEST_VCSDATAENTRY
_RUNTASKREQUEST.fields_by_name['scan_data'].message_type = _RUNTASKREQUEST_SCANDATAENTRY
_RUNTASKREQUEST.fields_by_name['env_data'].message_type = _RUNTASKREQUEST_ENVDATAENTRY
_GETRESULTSRESPONSE.fields_by_name['results'].message_type = strobesbufs_dot_analyzers_dot_analyzers__pb2._RESULT
DESCRIPTOR.message_types_by_name['RunTaskRequest'] = _RUNTASKREQUEST
DESCRIPTOR.message_types_by_name['RunTaskResponse'] = _RUNTASKRESPONSE
DESCRIPTOR.message_types_by_name['TaskStatusRequest'] = _TASKSTATUSREQUEST
DESCRIPTOR.message_types_by_name['TaskStatusResponse'] = _TASKSTATUSRESPONSE
DESCRIPTOR.message_types_by_name['StopTaskRequest'] = _STOPTASKREQUEST
DESCRIPTOR.message_types_by_name['StopTaskResponse'] = _STOPTASKRESPONSE
DESCRIPTOR.message_types_by_name['GetResultsRequest'] = _GETRESULTSREQUEST
DESCRIPTOR.message_types_by_name['GetResultsResponse'] = _GETRESULTSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RunTaskRequest = _reflection.GeneratedProtocolMessageType('RunTaskRequest', (_message.Message,), {

  'VcsDataEntry' : _reflection.GeneratedProtocolMessageType('VcsDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTASKREQUEST_VCSDATAENTRY,
    '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.VcsDataEntry)
    })
  ,

  'ScanDataEntry' : _reflection.GeneratedProtocolMessageType('ScanDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTASKREQUEST_SCANDATAENTRY,
    '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.ScanDataEntry)
    })
  ,

  'EnvDataEntry' : _reflection.GeneratedProtocolMessageType('EnvDataEntry', (_message.Message,), {
    'DESCRIPTOR' : _RUNTASKREQUEST_ENVDATAENTRY,
    '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
    # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest.EnvDataEntry)
    })
  ,
  'DESCRIPTOR' : _RUNTASKREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskRequest)
  })
_sym_db.RegisterMessage(RunTaskRequest)
_sym_db.RegisterMessage(RunTaskRequest.VcsDataEntry)
_sym_db.RegisterMessage(RunTaskRequest.ScanDataEntry)
_sym_db.RegisterMessage(RunTaskRequest.EnvDataEntry)

RunTaskResponse = _reflection.GeneratedProtocolMessageType('RunTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNTASKRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.RunTaskResponse)
  })
_sym_db.RegisterMessage(RunTaskResponse)

TaskStatusRequest = _reflection.GeneratedProtocolMessageType('TaskStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _TASKSTATUSREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskStatusRequest)
  })
_sym_db.RegisterMessage(TaskStatusRequest)

TaskStatusResponse = _reflection.GeneratedProtocolMessageType('TaskStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _TASKSTATUSRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.TaskStatusResponse)
  })
_sym_db.RegisterMessage(TaskStatusResponse)

StopTaskRequest = _reflection.GeneratedProtocolMessageType('StopTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPTASKREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.StopTaskRequest)
  })
_sym_db.RegisterMessage(StopTaskRequest)

StopTaskResponse = _reflection.GeneratedProtocolMessageType('StopTaskResponse', (_message.Message,), {
  'DESCRIPTOR' : _STOPTASKRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.StopTaskResponse)
  })
_sym_db.RegisterMessage(StopTaskResponse)

GetResultsRequest = _reflection.GeneratedProtocolMessageType('GetResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSREQUEST,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.GetResultsRequest)
  })
_sym_db.RegisterMessage(GetResultsRequest)

GetResultsResponse = _reflection.GeneratedProtocolMessageType('GetResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESULTSRESPONSE,
  '__module__' : 'strobesbufs.analyzers.analyzers_service_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.analyzers.analyzer_service.GetResultsResponse)
  })
_sym_db.RegisterMessage(GetResultsResponse)


_RUNTASKREQUEST_VCSDATAENTRY._options = None
_RUNTASKREQUEST_SCANDATAENTRY._options = None
_RUNTASKREQUEST_ENVDATAENTRY._options = None

_RUNNERSERVICE = _descriptor.ServiceDescriptor(
  name='RunnerService',
  full_name='strobesbufs.analyzers.analyzer_service.RunnerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=954,
  serialized_end=1496,
  methods=[
  _descriptor.MethodDescriptor(
    name='RunTask',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.RunTask',
    index=0,
    containing_service=None,
    input_type=_RUNTASKREQUEST,
    output_type=_RUNTASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TaskStatus',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.TaskStatus',
    index=1,
    containing_service=None,
    input_type=_TASKSTATUSREQUEST,
    output_type=_TASKSTATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StopTask',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.StopTask',
    index=2,
    containing_service=None,
    input_type=_STOPTASKREQUEST,
    output_type=_STOPTASKRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetResults',
    full_name='strobesbufs.analyzers.analyzer_service.RunnerService.GetResults',
    index=3,
    containing_service=None,
    input_type=_GETRESULTSREQUEST,
    output_type=_GETRESULTSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RUNNERSERVICE)

DESCRIPTOR.services_by_name['RunnerService'] = _RUNNERSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/tasks/task.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from strobesbufs.messier import common_pb2 as strobesbufs_dot_messier_dot_common__pb2
from strobesbufs.messier.functions import function_pb2 as strobesbufs_dot_messier_dot_functions_dot_function__pb2
from strobesbufs.messier.analyzers import analyzer_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_analyzer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/tasks/task.proto',
  package='strobesbufs.messier.task',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$strobesbufs/messier/tasks/task.proto\x12\x18strobesbufs.messier.task\x1a\x1fgoogle/protobuf/timestamp.proto\x1a strobesbufs/messier/common.proto\x1a,strobesbufs/messier/functions/function.proto\x1a,strobesbufs/messier/analyzers/analyzer.proto\"\xcb\x02\n\x04Task\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\x06status\x18\x02 \x01(\x0e\x32\".strobesbufs.messier.common.Status\x12+\n\x07started\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05\x65nded\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x08\x61nalyzer\x18\x05 \x01(\x0b\x32&.strobesbufs.messier.analyzer.AnalyzerH\x00\x12:\n\x08\x66unction\x18\x06 \x01(\x0b\x32&.strobesbufs.messier.function.FunctionH\x00\x12\x12\n\ndepends_on\x18\x07 \x01(\t\x12\x10\n\x08parallel\x18\x08 \x01(\x08\x42\x0b\n\ttask_typeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_common__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_functions_dot_function__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_analyzer__pb2.DESCRIPTOR,])




_TASK = _descriptor.Descriptor(
  name='Task',
  full_name='strobesbufs.messier.task.Task',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='strobesbufs.messier.task.Task.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='strobesbufs.messier.task.Task.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='started', full_name='strobesbufs.messier.task.Task.started', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ended', full_name='strobesbufs.messier.task.Task.ended', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analyzer', full_name='strobesbufs.messier.task.Task.analyzer', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='function', full_name='strobesbufs.messier.task.Task.function', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depends_on', full_name='strobesbufs.messier.task.Task.depends_on', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parallel', full_name='strobesbufs.messier.task.Task.parallel', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='task_type', full_name='strobesbufs.messier.task.Task.task_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=226,
  serialized_end=557,
)

_TASK.fields_by_name['status'].enum_type = strobesbufs_dot_messier_dot_common__pb2._STATUS
_TASK.fields_by_name['started'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TASK.fields_by_name['ended'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TASK.fields_by_name['analyzer'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_analyzer__pb2._ANALYZER
_TASK.fields_by_name['function'].message_type = strobesbufs_dot_messier_dot_functions_dot_function__pb2._FUNCTION
_TASK.oneofs_by_name['task_type'].fields.append(
  _TASK.fields_by_name['analyzer'])
_TASK.fields_by_name['analyzer'].containing_oneof = _TASK.oneofs_by_name['task_type']
_TASK.oneofs_by_name['task_type'].fields.append(
  _TASK.fields_by_name['function'])
_TASK.fields_by_name['function'].containing_oneof = _TASK.oneofs_by_name['task_type']
DESCRIPTOR.message_types_by_name['Task'] = _TASK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Task = _reflection.GeneratedProtocolMessageType('Task', (_message.Message,), {
  'DESCRIPTOR' : _TASK,
  '__module__' : 'strobesbufs.messier.tasks.task_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.task.Task)
  })
_sym_db.RegisterMessage(Task)


# @@protoc_insertion_point(module_scope)



from google.protobuf.struct_pb2 import Struct
from strobesbufs.analyzers.enums import SeverityType
from google.protobuf.json_format import MessageToDict
from strobesbufs.analyzers import analyzers_pb2 as pb2


class ProtoWrapper:
    def __init__(self, analyzer):
        self.result = pb2.Result()
        self.scan_meta = pb2.ScanMeta()
        self.bugs_list = []
        self.result.analyzer = getattr(pb2.Result.Analyzer, analyzer.upper())
        self.report = None

    def add_bug_count(self, severity: int):
        self.scan_meta.total_bugs += 1
        setattr(self.scan_meta, SeverityType(severity).name,
                getattr(self.scan_meta,
                        SeverityType(severity).name) + 1)

    def generate_report(self):
        self.result.bugs_list.extend(self.bugs_list)
        self.result.scan_meta.CopyFrom(self.scan_meta)
        self.report = MessageToDict(
            self.result, including_default_value_fields=True)

    @staticmethod
    def create_sast_object(**kwargs) -> pb2.SAST:
        sast = pb2.SAST()
        if "file_name" in kwargs:
            sast.file_name = kwargs.get("file_name")
        if "vulnerable_code" in kwargs:
            sast.vulnerable_code = kwargs.get("vulnerable_code")
        if "start_line_no" in kwargs:
            sast.start_line_no = kwargs.get("start_line_no")
        if "end_line_no" in kwargs:
            sast.end_line_no = kwargs.get("end_line_no")
        return sast

    @staticmethod
    def create_dast_object(**kwargs) -> pb2.DAST:
        dast = pb2.DAST()
        if "uri" in kwargs:
            uri = kwargs.get("uri")
            if isinstance(uri, list):
                dast.uri.extend(uri)
        if "port" in kwargs:
            port = kwargs.get("port")
            if isinstance(port, int):
                dast.port = port
        if "method" in kwargs:
            dast.method = kwargs.get("method")
        if "param" in kwargs:
            dast.param = kwargs.get("param")
        if "evidence" in kwargs:
            dast.evidence = kwargs.get("evidence")
        return dast

    @staticmethod
    def create_network_object(**kwargs) -> pb2.Network:
        network = pb2.Network()
        if "ipaddress" in kwargs:
            network.ipaddress = kwargs.get("ipaddress")
        if "port" in kwargs:
            network.port = kwargs.get("port")
        if "hostname" in kwargs:
            network.hostname = kwargs.get("hostname")
        if "macaddress" in kwargs:
            network.macaddress = kwargs.get("macaddress")
        if "cpe" in kwargs:
            network.cpe = kwargs.get("cpe")
        return network

    @staticmethod
    def create_package_object(**kwargs) -> pb2.Package:
        package = pb2.Package()
        if "name" in kwargs:
            package.name = kwargs.get("name")
        if "installed_version" in kwargs:
            package.installed_version = kwargs.get("installed_version")
        if "affected_versions" in kwargs:
            package.affected_versions = kwargs.get("affected_versions")
        return package

    @staticmethod
    def create_container_object(**kwargs) -> pb2.Container:
        container = pb2.Container()
        if "package_name" in kwargs:
            container.package_name = kwargs.get("package_name")
        if "fixed_version" in kwargs:
            container.fixed_version = kwargs.get("fixed_version")
        if "installed_version" in kwargs:
            container.installed_version = kwargs.get("installed_version")
        if "cpe" in kwargs:
            container.cpe = kwargs.get("cpe")
        return container

    @staticmethod
    def create_cloud_object(**kwargs) -> pb2.Cloud:
        cloud = pb2.Cloud()
        if "region" in kwargs:
            cloud.region = kwargs.get("region")
        if "aws" in kwargs:
            aws_details = kwargs.get("aws")
            if isinstance(aws_details, dict):
                aws_details = ProtoWrapper.create_aws_object(**aws_details)
            if isinstance(aws_details, pb2.AWS):
                cloud.aws.CopyFrom(aws_details)
        return cloud

    @staticmethod
    def create_aws_object(**kwargs) -> pb2.AWS:
        aws = pb2.AWS()
        if "resource_id" in kwargs:
            aws.resource_id = kwargs.get("resource_id")
        if "type" in kwargs:
            aws_type = kwargs.get("type")
            if isinstance(aws_type, int):
                aws.type = aws_type
        if "category" in kwargs:
            aws.category = kwargs.get("category")
        return aws

    @staticmethod
    def create_bug_object(**kwargs) -> pb2.Bug:
        bug = pb2.Bug()
        if "title" in kwargs:
            bug.title = kwargs.get("title")
        if "description" in kwargs:
            bug.description = kwargs.get("description")
        if "severity" in kwargs:
            severity = kwargs.get("severity")
            if isinstance(severity, int):
                bug.severity = severity
        if "CVSS" in kwargs:
            cvss = kwargs.get("CVSS")
            if isinstance(cvss, float):
                bug.CVSS = cvss
        if "step_to_reproduce" in kwargs:
            bug.step_to_reproduce = kwargs.get("step_to_reproduce")
        if "mitigation" in kwargs:
            bug.mitigation = kwargs.get("mitigation")
        if "CVE" in kwargs:
            cve = kwargs.get("CVE")
            if isinstance(cve, list):
                bug.CVE.extend(cve)
        if "CWE" in kwargs:
            cwe = kwargs.get("CWE")
            if isinstance(cwe, list):
                bug.CWE.extend(cwe)
        if "references" in kwargs:
            references = kwargs.get("references")
            if isinstance(references, list):
                bug.references.extend(references)
        if "sast" in kwargs:
            sast = kwargs.get("sast")
            if isinstance(sast, pb2.SAST):
                bug.sast.CopyFrom(sast)
        if "dast" in kwargs:
            dast = kwargs.get("dast")
            if isinstance(dast, pb2.DAST):
                bug.dast.CopyFrom(dast)
        if "network" in kwargs:
            network = kwargs.get("network")
            if isinstance(network, pb2.Network):
                bug.network.CopyFrom(network)
        if "cloud" in kwargs:
            cloud = kwargs.get("cloud")
            if isinstance(cloud, pb2.Cloud):
                bug.cloud.CopyFrom(cloud)
        if "package" in kwargs:
            package = kwargs.get("package")
            if isinstance(package, pb2.Packgae):
                bug.package.CopyFrom(package)
        if "container" in kwargs:
            container = kwargs.get("container")
            if isinstance(container, pb2.Container):
                bug.container.CopyFrom(container)
        if "tags" in kwargs:
            tags = kwargs.get("tags")
            if isinstance(tags, list):
                bug.tags.extend(tags)
        if "extra_info" in kwargs:
            extra_info = kwargs.get("extra_info")
            if isinstance(extra_info, dict):
                struct = Struct()
                struct.update(extra_info)
            elif isinstance(extra_info, Struct):
                struct = extra_info
            bug.extra_info.CopyFrom(struct)
        if "scan_details" in kwargs:
            scan_details = kwargs.get("scan_details")
            if isinstance(scan_details, dict):
                for key, value in scan_details.items():
                    bug.scan_details[key] = value
        if "assets" in kwargs:
            assets = kwargs.get("assets")
            if isinstance(assets, dict):
                for key, value in assets.items():
                    bug.assets[key] = value
        return bug



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/analyzers/naabu.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.messier import common_pb2 as strobesbufs_dot_messier_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/analyzers/naabu.proto',
  package='strobesbufs.messier.analyzer',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)strobesbufs/messier/analyzers/naabu.proto\x12\x1cstrobesbufs.messier.analyzer\x1a strobesbufs/messier/common.proto\"J\n\x05Naabu\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x31\n\x03log\x18\x02 \x01(\x0e\x32$.strobesbufs.messier.common.LogLevelb\x06proto3'
  ,
  dependencies=[strobesbufs_dot_messier_dot_common__pb2.DESCRIPTOR,])




_NAABU = _descriptor.Descriptor(
  name='Naabu',
  full_name='strobesbufs.messier.analyzer.Naabu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='target', full_name='strobesbufs.messier.analyzer.Naabu.target', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='log', full_name='strobesbufs.messier.analyzer.Naabu.log', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=183,
)

_NAABU.fields_by_name['log'].enum_type = strobesbufs_dot_messier_dot_common__pb2._LOGLEVEL
DESCRIPTOR.message_types_by_name['Naabu'] = _NAABU
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Naabu = _reflection.GeneratedProtocolMessageType('Naabu', (_message.Message,), {
  'DESCRIPTOR' : _NAABU,
  '__module__' : 'strobesbufs.messier.analyzers.naabu_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.analyzer.Naabu)
  })
_sym_db.RegisterMessage(Naabu)


# @@protoc_insertion_point(module_scope)



""" __Doc__ File handle class """
from setuptools import find_packages, setup
from strobesbufs.__version__ import __version__


with open("README.md") as file:
    setup(
        name="Strobesbufs",
        license="GPLv3",
        description="Contains all the protos created by strobesbuf as a package to use",
        long_description=file.read(),
        long_description_content_type="text/markdown",
        author="Akhil Reni",
        version=__version__,
        author_email="akhil@wesecureapp.com",
        url="https://github.com/strobes-co/strobesbufs-py",
        packages=find_packages(),
        python_requires='>=3.6',
        install_requires=[
            "grpcio==1.30.0",
            "grpcio-tools==1.30.0"
        ],
        include_package_data=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: strobesbufs/messier/analyzers/analyzer.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from strobesbufs.messier.analyzers import bandit_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_bandit__pb2
from strobesbufs.messier.analyzers import subfinder_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_subfinder__pb2
from strobesbufs.messier.analyzers import naabu_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_naabu__pb2
from strobesbufs.messier.analyzers import wappalyzer_pb2 as strobesbufs_dot_messier_dot_analyzers_dot_wappalyzer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='strobesbufs/messier/analyzers/analyzer.proto',
  package='strobesbufs.messier.analyzer',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,strobesbufs/messier/analyzers/analyzer.proto\x12\x1cstrobesbufs.messier.analyzer\x1a*strobesbufs/messier/analyzers/bandit.proto\x1a-strobesbufs/messier/analyzers/subfinder.proto\x1a)strobesbufs/messier/analyzers/naabu.proto\x1a.strobesbufs/messier/analyzers/wappalyzer.proto\"\x82\x02\n\x08\x41nalyzer\x12\x36\n\x06\x42\x61ndit\x18\x01 \x01(\x0b\x32$.strobesbufs.messier.analyzer.BanditH\x00\x12<\n\tSubfinder\x18\x02 \x01(\x0b\x32\'.strobesbufs.messier.analyzer.SubfinderH\x00\x12\x34\n\x05Naabu\x18\x03 \x01(\x0b\x32#.strobesbufs.messier.analyzer.NaabuH\x00\x12>\n\nWappalyzer\x18\x04 \x01(\x0b\x32(.strobesbufs.messier.analyzer.WappalyzerH\x00\x42\n\n\x08\x61nalyzerb\x06proto3'
  ,
  dependencies=[strobesbufs_dot_messier_dot_analyzers_dot_bandit__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_subfinder__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_naabu__pb2.DESCRIPTOR,strobesbufs_dot_messier_dot_analyzers_dot_wappalyzer__pb2.DESCRIPTOR,])




_ANALYZER = _descriptor.Descriptor(
  name='Analyzer',
  full_name='strobesbufs.messier.analyzer.Analyzer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='Bandit', full_name='strobesbufs.messier.analyzer.Analyzer.Bandit', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Subfinder', full_name='strobesbufs.messier.analyzer.Analyzer.Subfinder', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Naabu', full_name='strobesbufs.messier.analyzer.Analyzer.Naabu', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Wappalyzer', full_name='strobesbufs.messier.analyzer.Analyzer.Wappalyzer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='analyzer', full_name='strobesbufs.messier.analyzer.Analyzer.analyzer',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=261,
  serialized_end=519,
)

_ANALYZER.fields_by_name['Bandit'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_bandit__pb2._BANDIT
_ANALYZER.fields_by_name['Subfinder'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_subfinder__pb2._SUBFINDER
_ANALYZER.fields_by_name['Naabu'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_naabu__pb2._NAABU
_ANALYZER.fields_by_name['Wappalyzer'].message_type = strobesbufs_dot_messier_dot_analyzers_dot_wappalyzer__pb2._WAPPALYZER
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Bandit'])
_ANALYZER.fields_by_name['Bandit'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Subfinder'])
_ANALYZER.fields_by_name['Subfinder'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Naabu'])
_ANALYZER.fields_by_name['Naabu'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
_ANALYZER.oneofs_by_name['analyzer'].fields.append(
  _ANALYZER.fields_by_name['Wappalyzer'])
_ANALYZER.fields_by_name['Wappalyzer'].containing_oneof = _ANALYZER.oneofs_by_name['analyzer']
DESCRIPTOR.message_types_by_name['Analyzer'] = _ANALYZER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Analyzer = _reflection.GeneratedProtocolMessageType('Analyzer', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZER,
  '__module__' : 'strobesbufs.messier.analyzers.analyzer_pb2'
  # @@protoc_insertion_point(class_scope:strobesbufs.messier.analyzer.Analyzer)
  })
_sym_db.RegisterMessage(Analyzer)


# @@protoc_insertion_point(module_scope)
